@@ -12,7 +12,7 @@ import urllib
 import urllib2
 import re
 
-__version__  = '0.10.5'
+__version__  = '0.10.6'
 __author__ = "Hiroki Ohtani (liris.pp@gmail.com)"
 __contributors__ = ["Junji NAKANISHI <daemonfreaks@gmail.com>"]
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
@@ -885,13 +885,18 @@ class Node(object):
                                 rdattrs[elems[0]] = elems[1]
 
                     inSnippet = False
+                    snippetEnd = border + ":END"
                     while len(lines):
                         rdline = lines.pop(0)
                         if not rdline:
+                        #    break
                             if not inSnippet:
                                 inSnippet = True
                             else:
                                 break
+                        if rdline == snippetEnd:
+                            isend = True
+                            break
                         sb.append(rdline)
                     rduri = rdattrs.setdefault("@uri", None)
                     rdsnippet = "\n".join(sb)
